function dummy=im_plot(F,xy,clr,N,tol)
%____________________________________________
%
%    IM_PLOT
%____________________________________________
% Plots the graph of a function given implicitly
% 
% Input arguments:
%    F   - name of the function (a string);
%   xy   - array of four numbers [xmin xmax ymin ymax],
%          determines the area to be shown;
%   clr  - graph color and plot style (a string), e.g., '.g'
%          means to Matlab's plot: "color green, do not connect points";
%    N   - number of subintervals, see below;
%   tol  - tolerance in a stopping criterion.
%          
%  Output argument:
%  dummy - whatever you want.
%  
%  Method: 
%     The intervals [ymin,ymax] and [xmin,xmax] are divided
%     each into N equal subintervals. For each y_i, an end of a
%     y-subinterval, "fzero" is called to find a root of 
%     F(x,y_j) in each x-subinterval [x_j,x_{j+1}] where this
%     function changes sign. Points so found are plotted.
%
a=[];
b=[];
xv=ones(1,2);
intX=(xy(2)-xy(1))/N;
intY=(xy(4)-xy(3))/N;
options=optimset('TolX',tol);
for y=xy(3):intY:xy(4)
    for x=xy(1):intX:xy(2)
        xv(1)=x;
        xv(2)=x+intX;
        if (feval(F,xv(1),y)*feval(F,xv(2),y)<=0)
            a=[a fzero(F,xv,options,y)];
            b=[b y];
        end
    end
end
plot(a,b,clr);