function [x,y] = secant(F,x0,x1,tol,maxit)
% _____________________________________
%
% SECANT
% _____________________________________
% 
% Finds a zero of a real function y=F(x) of a
% single real variable x using the secant method.
%
%     
% Input arguments:
%      F - name of the function (a string);
%  x0,x1 - initial points;
%    tol - tolerance;
%  maxit - maximal number of iterations.
%
% Output arguments:
%      x - solution found;
%      y - value of F at the point x.
%
% Stopping criterion:
%    (abs(F(x_i)) < tol)  or (i == maxit),
% where i is the iteration number, x_i - approximate 
% root found at the iteration i.
f=feval(F,x0);
y=feval(F,x1);
for i=2:maxit
    x=x1-y*(x1-x0)/(y-f);
    x0=x1;
    x1=x;
    f=y;
    y=feval(F,x1);
    if (abs(y)<tol)
        break
    end
end